==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/BDDPropagator.h <==
// public final class soot.jimple.spark.solver.BDDPropagator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c9353bf3415021d soot_jimple_spark_solver_BDDPropagator
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_BDDPropagator_H_
#define _JC_soot_jimple_spark_solver_BDDPropagator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs	_jc_soot_jimple_spark_solver_BDDPropagator$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs	_jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$refs	_jc_soot_jimple_spark_solver_BDDPropagator$refs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$nonrefs	_jc_soot_jimple_spark_solver_BDDPropagator$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$object	_jc_soot_jimple_spark_solver_BDDPropagator$object;

typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vmethods	_jc_soot_jimple_spark_solver_BDDPropagator$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vtable	_jc_soot_jimple_spark_solver_BDDPropagator$vtable;
typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vtype	_jc_soot_jimple_spark_solver_BDDPropagator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_BDDPropagator$method$_init$a580f473db5d2f29(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_BDDPropagator$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_BDDPropagator$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_BDDPropagator$vmethods {
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_BDDPropagator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_BDDPropagator$vmethods	soot_jimple_spark_solver_BDDPropagator;
};

// Vtype
struct _jc_soot_jimple_spark_solver_BDDPropagator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_BDDPropagator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs {
	struct _jc_soot_jimple_spark_pag_BDDPAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_BDDPropagator$refs {
    _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs	soot_jimple_spark_solver_BDDPropagator;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_BDDPropagator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs	soot_jimple_spark_solver_BDDPropagator;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_BDDPropagator$object {
	_jc_soot_jimple_spark_solver_BDDPropagator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_BDDPropagator$vtype	*vtype;
	_jc_soot_jimple_spark_solver_BDDPropagator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_BDDPropagator$vtype _jc_soot_jimple_spark_solver_BDDPropagator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_BDDPropagator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_BDDPropagator$class_object;

#endif	/* _JC_soot_jimple_spark_solver_BDDPropagator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/BDDPropagator.h <==
// public final class soot.jimple.spark.solver.BDDPropagator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6c9353bf3415021d soot_jimple_spark_solver_BDDPropagator
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_BDDPropagator_H_
#define _JC_soot_jimple_spark_solver_BDDPropagator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_BDDPAG$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs	_jc_soot_jimple_spark_solver_BDDPropagator$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs	_jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$refs	_jc_soot_jimple_spark_solver_BDDPropagator$refs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$nonrefs	_jc_soot_jimple_spark_solver_BDDPropagator$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_BDDPropagator$object	_jc_soot_jimple_spark_solver_BDDPropagator$object;

typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vmethods	_jc_soot_jimple_spark_solver_BDDPropagator$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vtable	_jc_soot_jimple_spark_solver_BDDPropagator$vtable;
typedef const struct _jc_soot_jimple_spark_solver_BDDPropagator$vtype	_jc_soot_jimple_spark_solver_BDDPropagator$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_BDDPropagator$method$_init$a580f473db5d2f29(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *, struct _jc_soot_jimple_spark_pag_BDDPAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_BDDPropagator$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_BDDPropagator$method_info$propagate$430f3309bbb43666;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_BDDPropagator$vmethods {
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_BDDPropagator$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_BDDPropagator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_BDDPropagator$vmethods	soot_jimple_spark_solver_BDDPropagator;
};

// Vtype
struct _jc_soot_jimple_spark_solver_BDDPropagator$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_BDDPropagator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs {
	struct _jc_soot_jimple_spark_pag_BDDPAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_BDDPropagator$refs {
    _jc_soot_jimple_spark_solver_BDDPropagator$sub_refs	soot_jimple_spark_solver_BDDPropagator;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_BDDPropagator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_BDDPropagator$sub_nonrefs	soot_jimple_spark_solver_BDDPropagator;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_BDDPropagator$object {
	_jc_soot_jimple_spark_solver_BDDPropagator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_BDDPropagator$vtype	*vtype;
	_jc_soot_jimple_spark_solver_BDDPropagator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_BDDPropagator$vtype _jc_soot_jimple_spark_solver_BDDPropagator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_BDDPropagator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_BDDPropagator$class_object;

#endif	/* _JC_soot_jimple_spark_solver_BDDPropagator_H_ */
